@@ -11,14 +11,32 @@ sub new {
     return $self;
 }
 
+sub new_from_backup_header {
+    my ($class, $header) = @_;
+    my $self = bless {}, $class;
+    $self->{path} = $header->{"BackupPath"} or
+        die "No BackupPath specified in the backup metafile.\n";
+    unless (-d $self->{path}) {
+        die "Restore path $self->{path} doesn't exist.\n";
+    }
+    return $self;
+}
+
+sub backup_header {
+    my $self = shift;
+    return {
+        "BackupPath" => $self->{path},
+    };
+}
+
 sub chunkpath {
     my ($self, $dig) = @_;
     my @parts;
     my $fulldig = $dig;
     $dig =~ s/^\w+://; # remove the "hashtype:" from beginning
     while (length $dig && @parts < 4) {
-	$dig =~ s/^(.{1,4})//;
-	push @parts, $1;
+        $dig =~ s/^(.{1,4})//;
+        push @parts, $1;
     }
     return $self->{path} . "/" . join("/", @parts) . "/$fulldig.chunk";
 }
@@ -27,9 +45,15 @@ sub has_chunk {
     my ($self, $chunk) = @_;
     my $dig = $chunk->backup_digest;   # "sha1:sdfsdf" format scalar
     my $path = $self->chunkpath($dig);
-    my $exists = -e $path;
-    warn "Doesn't exist: $path ($dig)" unless $exists;
-    return $exists;
+    return -e $path;
+}
+
+sub load_chunk {
+    my ($self, $dig) = @_;
+    my $path = $self->chunkpath($dig);
+    open (my $fh, $path) or die "Error opening $path to load chunk: $!";
+    my $chunk = do { local $/; <$fh>; };
+    return \$chunk;
 }
 
 sub store_chunk {
@@ -38,17 +62,23 @@ sub store_chunk {
     my $blen = $chunk->backup_length;
     my $len = $chunk->length;
 
-    warn "Storing chunk: $dig\n";
-
     my $path = $self->chunkpath($dig);
     my $dir = $path;
     $dir =~ s!/[^/]+$!!;
     unless (-d $dir) {
-	File::Path::mkpath($dir) or die "Failed to mkdir: $dir: $!\n";
+        File::Path::mkpath($dir) or die "Failed to mkdir: $dir: $!\n";
     }
     open (my $fh, ">$path") or die "Failed to open $path for writing: $!\n";
-    print $fh ${ $chunk->chunkref };
+    my $chunkref = $chunk->chunkref;
+    print $fh $$chunkref;
     close($fh) or die "Failed to close $path\n";
+
+    my $actual_size   = -s $path;
+    my $expected_size = length $$chunkref;
+    unless ($actual_size == $expected_size) {
+        die "Chunk was written to disk wrong:  size is $actual_size, expecting $expected_size\n";
+    }
+
     return 1;
 }
 
@@ -56,7 +86,7 @@ sub store_backup_meta {
     my ($self, $name, $file) = @_;
     my $dir = "$self->{path}/backups/";
     unless (-d $dir) {
-	mkdir $dir or die "Failed to mkdir $dir: $!\n";
+        mkdir $dir or die "Failed to mkdir $dir: $!\n";
     }
     open (my $fh, ">$dir/$name.brackup") or die;
     print $fh $file;
